@@ -7,11 +7,11 @@ from sklearn.base import BaseEstimator
 from sklearn.model_selection import cross_val_score, train_test_split
 from sklearn.tree import DecisionTreeClassifier
 
-from imodels.tree.shrunk_tree import ShrunkTreeRegressor, ShrunkTreeClassifier
+from imodels.tree.hierarchical_shrinkage import HSTreeRegressor, HSTreeClassifier
 from imodels.util.tree import compute_tree_complexity
 
 
-class DecisionTreeClassifierCCP(DecisionTreeClassifier):
+class DecisionTreeCCPClassifier(DecisionTreeClassifier):
     def __init__(self, estimator_: BaseEstimator, desired_complexity: int = 1, complexity_measure='max_rules', *args,
                  **kwargs):
         self.desired_complexity = desired_complexity
@@ -19,22 +19,6 @@ class DecisionTreeClassifierCCP(DecisionTreeClassifier):
         self.estimator_ = estimator_
         self.complexity_measure = complexity_measure
 
-    # def fit(self,X,y,sample_weight=None,*args, **kwargs):
-    #    path = self.estimator_.cost_complexity_pruning_path(X,y)
-    #    ccp_alphas, impurities = path.ccp_alphas, path.impurities
-    #    complexities = {}
-    #    for alpha in ccp_alphas: 
-    #        est_params = self.estimator_.get_params()
-    #        est_params['ccp_alpha'] = alpha
-    ##        copied_estimator =  deepcopy(self.estimator_).set_params(**est_params)
-    #       copied_estimator.fit(X, y)
-    #       complexities[alpha] = self._get_complexity(copied_estimator)
-    #   closest_alpha, closest_leaves = min(complexities.items(), key=lambda x: abs(self.desired_complexity - x[1]))
-    #   params_for_fitting = self.estimator_.get_params()
-    #   params_for_fitting['ccp_alpha'] = closest_alpha
-    #   self.estimator_.set_params(**params_for_fitting)
-    #   self.estimator_.fit(X,y,*args, **kwargs)
-
     def _get_alpha(self, X, y, sample_weight=None, *args, **kwargs):
         path = self.estimator_.cost_complexity_pruning_path(X, y)
         ccp_alphas, impurities = path.ccp_alphas, path.impurities
@@ -91,7 +75,7 @@ class DecisionTreeClassifierCCP(DecisionTreeClassifier):
             return NotImplemented
 
 
-class DecisionTreeRegressorCCP(BaseEstimator):
+class DecisionTreeCCPRegressor(BaseEstimator):
 
     def __init__(self, estimator_: BaseEstimator, desired_complexity: int = 1, complexity_measure='max_rules', *args,
                  **kwargs):
@@ -154,7 +138,7 @@ class DecisionTreeRegressorCCP(BaseEstimator):
             return NotImplemented
 
 
-class ShrunkDecisionTreeRegressorCCP_CV(ShrunkTreeRegressor):
+class HSDecisionTreeCCPRegressorCV(HSTreeRegressor):
     def __init__(self, estimator_: BaseEstimator, reg_param_list: List[float] = [0.1, 1, 10, 50, 100, 500],
                  desired_complexity: int = 1, cv: int = 3, scoring=None, *args, **kwargs):
         super().__init__(estimator_=estimator_, reg_param=None)
@@ -164,18 +148,18 @@ class ShrunkDecisionTreeRegressorCCP_CV(ShrunkTreeRegressor):
         self.desired_complexity = desired_complexity
 
     def fit(self, X, y, sample_weight=None, *args, **kwargs):
-        m = DecisionTreeRegressorCCP(self.estimator_, desired_complexity=self.desired_complexity)
+        m = DecisionTreeCCPRegressor(self.estimator_, desired_complexity=self.desired_complexity)
         m.fit(X, y, sample_weight, *args, **kwargs)
         self.scores_ = []
         for reg_param in self.reg_param_list:
-            est = ShrunkTreeRegressor(deepcopy(m.estimator_), reg_param)
+            est = HSTreeRegressor(deepcopy(m.estimator_), reg_param)
             cv_scores = cross_val_score(est, X, y, cv=self.cv, scoring=self.scoring)
             self.scores_.append(np.mean(cv_scores))
         self.reg_param = self.reg_param_list[np.argmax(self.scores_)]
         super().fit(X=X, y=y)
 
 
-class ShrunkDecisionTreeClassifierCCP_CV(ShrunkTreeClassifier):
+class HSDecisionTreeCCPClassifierCV(HSTreeClassifier):
     def __init__(self, estimator_: BaseEstimator, reg_param_list: List[float] = [0.1, 1, 10, 50, 100, 500],
                  desired_complexity: int = 1, cv: int = 3, scoring=None, *args, **kwargs):
         super().__init__(estimator_=estimator_, reg_param=None)
@@ -185,11 +169,11 @@ class ShrunkDecisionTreeClassifierCCP_CV(ShrunkTreeClassifier):
         self.desired_complexity = desired_complexity
 
     def fit(self, X, y, sample_weight=None, *args, **kwargs):
-        m = DecisionTreeClassifierCCP(self.estimator_, desired_complexity=self.desired_complexity)
+        m = DecisionTreeCCPClassifier(self.estimator_, desired_complexity=self.desired_complexity)
         m.fit(X, y, sample_weight, *args, **kwargs)
         self.scores_ = []
         for reg_param in self.reg_param_list:
-            est = ShrunkTreeClassifier(deepcopy(m.estimator_), reg_param)
+            est = HSTreeClassifier(deepcopy(m.estimator_), reg_param)
             cv_scores = cross_val_score(est, X, y, cv=self.cv, scoring=self.scoring)
             self.scores_.append(np.mean(cv_scores))
         self.reg_param = self.reg_param_list[np.argmax(self.scores_)]
@@ -197,7 +181,7 @@ class ShrunkDecisionTreeClassifierCCP_CV(ShrunkTreeClassifier):
 
 
 if __name__ == '__main__':
-    m = DecisionTreeClassifierCCP(estimator_=DecisionTreeClassifier(random_state=1), desired_complexity=10,
+    m = DecisionTreeCCPClassifier(estimator_=DecisionTreeClassifier(random_state=1), desired_complexity=10,
                                   complexity_measure='max_leaf_nodes')
     # X,y = make_friedman1() #For regression
     X, y = datasets.load_breast_cancer(return_X_y=True)
@@ -207,7 +191,7 @@ if __name__ == '__main__':
     m.predict(X_test)
     print(m.score(X_test, y_test))
 
-    m = ShrunkDecisionTreeClassifierCCP_CV(estimator_=DecisionTreeClassifier(random_state=1), desired_complexity=10,
-                                           reg_param_list=[0.0, 0.1, 1.0, 5.0, 10.0, 25.0, 50.0, 100.0])
+    m = HSDecisionTreeCCPClassifierCV(estimator_=DecisionTreeClassifier(random_state=1), desired_complexity=10,
+                                       reg_param_list=[0.0, 0.1, 1.0, 5.0, 10.0, 25.0, 50.0, 100.0])
     m.fit(X_train, y_train)
     print(m.score(X_test, y_test))
