@@ -1,5 +1,9 @@
 import numpy as np
-from irf.ensemble import wrf
+
+try:
+    from irf.ensemble import wrf
+except:
+    from sklearn.ensemble import RandomForestClassifier as wrf
 from sklearn.base import BaseEstimator
 
 
@@ -8,9 +12,13 @@ class IRFClassifier(BaseEstimator):
         self.model = wrf()
         self.predict = self.model.predict
         self.predict_proba = self.model.predict_proba
+        try:
+            import irf
+        except:
+            raise Warning('irf not installed, defaulting to standard RandomForest. To install, run pip install irf')
 
     def fit(self, X, y, lambda_reg=0.1, sample_weight=None):
-        '''fit a linear model with integer coefficient and L1 regularization
+        '''Fit a linear model with integer coefficient and L1 regularization
         
         Params
         ------
@@ -26,6 +34,3 @@ class IRFClassifier(BaseEstimator):
         assert type(y) == np.ndarray, 'inputs should be ndarrays'
 
         self.model.fit(X, y, keep_record=False)
-
-
-
